@@ -1,19 +1,27 @@
 #' @title Tuning Spaces
 #'
 #' @description
-#' This is the abstract base class for tuning spaces which define a search space
-#' for hyperparameter tuning.
+#' This class defines a tuning space for hyperparameter tuning.
 #'
-#' `TuningSpace` objects store a list of [paradox::TuneToken] and additional
-#' meta information. These tokens can be assigned to the `$values` slot of
-#' a learner's [paradox::ParamSet].
+#' For tuning, it is important to create a search space that defines the range over which hyperparameters should be tuned.
+#' `TuningSpace` object consists of search spaces from peer-reviewed articles which work well for a wide range of data sets.
+#'
+#' The `$values` field stores a list of [paradox::TuneToken] which define the search space.
+#' These tokens can be assigned to the `$values` slot of a learner's [paradox::ParamSet].
+#' When the learner is tuned, the tokens are used to create the search space.
+#'
+#' @section S3 Methods:
+#' * `as.data.table.TuningSpace(x)`\cr
+#' Returns a tabular view of the tuning space.\cr
+#' [TuningSpace] -> [data.table::data.table()]\cr
+#'     * `x` ([TuningSpace])
 #'
 #' @export
 #' @examples
 #' library(mlr3tuning)
 #'
 #' # get default tuning space of rpart learner
-#' tuning_space = mlr_tuning_spaces$get("classif.rpart.default")
+#' tuning_space = lts("classif.rpart.default")
 #'
 #' # get learner and set tuning space
 #' learner = lrn("classif.rpart")
@@ -31,41 +39,72 @@
 #' instance$result
 TuningSpace = R6Class("TuningSpace",
   public = list(
-    #' @field id (`character(1)`).
+
+    #' @field id (`character(1)`)\cr
+    #'   Identifier of the object.
     id = NULL,
 
-    #' @field values (`list()`).
+    #' @field values (`list()`)\cr
+    #'   List of [paradox::TuneToken] that describe the tuning space and fixed parameter values.
     values = NULL,
 
-    #' @field tags (`character()`).
+    #' @field tags (`character()`)\cr
+    #'   Arbitrary tags to group and filter tuning space e.g. `"classification"` or "`regression`".
     tags = NULL,
 
-    #' @field package (`character()`).
+    #' @field learner (`character(1)`)\cr
+    #'   [mlr3::Learner] of the tuning space.
+    learner = NULL,
+
+    #' @field package (`character(1)`)\cr
+    #'   Packages which provide the [Learner], e.g. \CRANpkg{mlr3learners} for the learner
+    #'   [mlr3learners::LearnerClassifRanger] which interfaces the \CRANpkg{ranger} package.
     package = NULL,
 
-    #' @field learner (`character(1)`).
-    learner = NULL,
+    #' @field label (`character(1)`)\cr
+    #'   Label for this object.
+    #'   Can be used in tables, plot and text output instead of the ID.
+    label = NULL,
+
+    #' @field man (`character(1)`)\cr
+    #'   String in the format `[pkg]::[topic]` pointing to a manual page for this object.
+    #'   The referenced help package can be opened via method `$help()`.
+    man = NULL,
 
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     #'
     #' @param id (`character(1)`)\cr
     #'   Identifier for the new instance.
+    #'
     #' @param values (`list()`)\cr
-    #'   List of [paradox::TuneToken] and parameter values.
+    #'    List of [paradox::TuneToken] that describe the tuning space and fixed parameter values.
+    #'
     #' @param tags (`character()`)\cr
-    #'   Tags to group and filter tuning spaces.
+    #'   Tags to group and filter tuning spaces e.g. `"classification"` or "`regression`".
+    #'
     #' @param learner (`character(1)`)\cr
-    #'   [mlr3::Learner] identifier in [mlr3::mlr_learners].
+    #'   [mlr3::Learner] of the tuning space.
+    #'
     #' @param package (`character()`)\cr
     #'   Packages which provide the [Learner], e.g. \CRANpkg{mlr3learners} for the learner
     #'   [mlr3learners::LearnerClassifRanger] which interfaces the \CRANpkg{ranger} package.
-    initialize = function(id, values, tags, learner, package = character()) {
+    #'
+    #' @param label (`character(1)`)\cr
+    #'   Label for the new instance.
+    #'   Can be used in tables, plot and text output instead of the ID.
+    #'
+    #' @param man (`character(1)`)\cr
+    #'   String in the format `[pkg]::[topic]` pointing to a manual page for for the new instance.
+    #'   The referenced help package can be opened via method `$help()`.
+    initialize = function(id, values, tags, learner, package = character(), label = NA_character_, man = NA_character_) {
       self$id = assert_string(id, min.chars = 1L)
       self$learner = assert_string(learner, min.chars = 1L)
       self$values = assert_list(values, names = "unique")
       self$tags = assert_character(tags, any.missing = FALSE)
       self$package = union("mlr3tuningspaces", assert_character(package, any.missing = FALSE, min.chars = 1L))
+      self$label = assert_string(label, na.ok = TRUE)
+      self$man = assert_string(man, na.ok = TRUE)
     },
 
     #' @description
@@ -88,6 +127,12 @@ TuningSpace = R6Class("TuningSpace",
        sprintf("<%s:%s>", class(self)[1L], self$id)
     },
 
+    #' @description
+    #' Opens the corresponding help page referenced by field `$man`.
+    help = function() {
+      open_help(self$man)
+    },
+
     #' @description
     #' Printer.
     #'
@@ -103,15 +148,15 @@ TuningSpace = R6Class("TuningSpace",
           )
         }, .fill = TRUE)
       setcolorder(tab, c("id", "lower", "upper", "levels", "logscale"))
-      cat(format(self), sep = "\n")
+      catn(format(self), if (is.na(self$label)) "" else paste0(": ", self$label))
       print(tab)
     }
   )
 )
 
 #' @include mlr_tuning_spaces.R
-add_tuning_space = function(id, values, tags, learner, package = character()) { # nolint
-  tuning_space = TuningSpace$new(id, values, tags, learner, package)
+add_tuning_space = function(id, values, tags, learner, package = character(), label = NA_character_, man = NA_character_) { # nolint
+  tuning_space = TuningSpace$new(id, values, tags, learner, package, label = label, man = paste0("mlr3tuningspaces::", id))
   mlr_tuning_spaces$add(id, tuning_space)
 }
 
@@ -132,3 +177,23 @@ rd_info.TuningSpace = function(obj) { # nolint
     })
   )
 }
+
+#' @export
+as_search_space.TuningSpace = function(x, ...) { # nolint
+  x$get_learner()$param_set$search_space()
+}
+
+#' @export
+as.data.table.TuningSpace = function(x, ...) {
+  tab = map_dtr(x$values, function(value) {
+    if (test_class(value, "ObjectTuneToken")) {
+      as.data.table(value$content$param)[, c("lower", "upper", "levels")]
+    } else {
+      as.data.table(value$content)
+    }
+  }, .fill = TRUE)
+  tab[, "id" := names(x$values)]
+  setcolorder(tab, intersect(c("id", "lower", "upper", "levels", "logscale"), names(tab)))
+  if ("logscale" %in% names(tab)) tab[is.na(get("logscale")), "logscale" := FALSE]
+  tab[]
+}
